# -*- coding: utf-8 -*-

from django.contrib import admin
from django.utils.translation import ugettext as _

from .models import PaymentForm, PaymentInstallment


class PaymentInstallmentInline(admin.TabularInline):
    model = PaymentInstallment
    extra = 0
    fk_name = 'payment_form'
    fields = (
        'amount', 'days', 'end_month',
        'days_end_month', 'discount', 'fee'
    )


class PaymentFormAdmin(admin.ModelAdmin):
    fieldsets = (
        (_('general information'), {
            'fields': ('code', 'name', 'description', 'fee', 'discount',)
        }),
        (_('visualization admin'), {
            'fields': ('ordering', 'status',),
        }),
        (_('logs admin'), {
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify',),
        }),
    )
    search_fields = ('name',)
    list_display = (
        'get_status_display', 'get_code', 'name', 'fee', 'discount', 'ordering',
    )
    readonly_fields = ('creator', 'date_create', 'last_modifier', 'date_last_modify',)
    inlines = (PaymentInstallmentInline,)

    def get_code(self, obj):
        # per bordare di rosso i pagamenti con rate errate
        code = obj.code
        tot_amount = 0
        for installment in obj.installments.all():
            tot_amount += installment.amount
        if tot_amount != 100:
            code = "<span class='object_error'>{}</span>".format(obj.code)
        return code
    get_code.allow_tags = True
    get_code.admin_order_field = 'code'
    get_code.short_description = _('code')


class PaymentInstallmentAdmin(admin.ModelAdmin):
    fieldsets = (
        (_('general information'), {
            'fields': (
                'code', 'name', 'description', 'payment_form', 'amount', 'days',
                'end_month', 'days_end_month', 'fee', 'discount',
            )
        },),
        (_('visualization admin'), {
            'fields': ('ordering', 'status',),
        }),
        (_('logs admin'), {
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify',),
        }),
    )
    list_display = (
        'get_status_display', 'payment_form', 'code', 'name', 'amount', 'days', 'end_month',
        'days_end_month',
    )
    readonly_fields = ('creator', 'date_create', 'last_modifier', 'date_last_modify',)


admin.site.register(PaymentForm, PaymentFormAdmin)
admin.site.register(PaymentInstallment, PaymentInstallmentAdmin)
