# -*- coding: utf-8 -*-

from rest_framework import generics

from thux.api.views import QuerysetMixin
from thux.api.permissions import ThuxModelPermissions

from .. import models
from . import serializers


class PaymentFormList(QuerysetMixin, generics.ListAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.PaymentForm.objects.all()
    serializer_class = serializers.PaymentFormSerializer


class PaymentFormRetrieve(generics.RetrieveAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.PaymentForm.objects.all()
    serializer_class = serializers.PaymentFormSerializer


class PaymentFormCreate(generics.CreateAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.PaymentForm.objects.all()
    serializer_class = serializers.PaymentFormSerializerCreate


class PaymentFormUpdate(generics.UpdateAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.PaymentForm.objects.all()
    serializer_class = serializers.PaymentFormSerializerUpdate


class PaymentInstallmentList(QuerysetMixin, generics.ListAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.PaymentInstallment.objects.all()
    serializer_class = serializers.PaymentInstallmentSerializer

    def get_queryset(self):
        filters = self.get_filters()
        excludes = self.get_excludes()
        order_by = self.get_order_by()
        queryset = super(PaymentInstallmentList, self).get_queryset()
        queryset = queryset.filter(**filters).exclude(**excludes).order_by(*order_by).distinct()
        return queryset


class PaymentInstallmentRetrieve(generics.RetrieveAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.PaymentInstallment.objects.all()
    serializer_class = serializers.PaymentInstallmentSerializer


class PaymentInstallmentCreate(generics.CreateAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.PaymentInstallment.objects.all()
    serializer_class = serializers.PaymentInstallmentSerializerCreate


class PaymentInstallmentUpdate(generics.UpdateAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.PaymentInstallment.objects.all()
    serializer_class = serializers.PaymentInstallmentSerializerUpdate
